@@ -4,7 +4,11 @@
 #ifndef DEBUG_LOG_H
 #define DEBUG_LOG_H
 
-#ifdef NDEBUG
+#if (defined NDEBUG) && !(defined DEBUG_LOG_DISABLED)
+# define DEBUG_LOG_DISABLED
+#endif
+
+#ifdef DEBUG_LOG_DISABLED
 
 # if (defined __GNUC__) || ((defined __STDC_VERSION__) &&(__STDC_VERSION__ >= 199901L))
 #  define DebugLog(fmt, ...) ((void)(0))
@@ -12,7 +16,7 @@
 #  define DebugLog
 # endif
 
-#else /* DEBUG mode (not defined NDEBUG) */
+#else /* Enable DebugLog */
 /**
 * Please use C99 compiler to enable DebugLog() output.
 **/
@@ -131,6 +135,6 @@ DebugLog_Output(const char *file,
 
 # define DebugLog(fmt, ...) DebugLog_Output(__FILE__, __LINE__, __func__, fmt, ## __VA_ARGS__)
 
-#endif /* NDEBUG */
+#endif /* DEBUG_LOG_DISABLED */
 
 #endif /* DEBUG_LOG_H */
