@@ -322,7 +322,7 @@ WRMT_Impl_Poll(int *updated_device_index_pointer)
 WRMT_IOReturn
 WRMT_WiiRemoteImpl_Open(WRMT_WiiRemoteImpl *self)
 {
-	WRMT_IOReturn result = WRMT_IO_ERROR;
+	WRMT_IOReturn result = WRMT_IO_SUCCESS;
 	WRMT_Impl_Invaliant(self);
 	DebugLog("Hello\n");
 
@@ -337,6 +337,7 @@ WRMT_WiiRemoteImpl_Open(WRMT_WiiRemoteImpl *self)
 		if(control_socket == -1)
 		{
 			WRMT_SetError("Control Socket Creation Failed.");
+			result = WRMT_IO_ERROR;
 			return result;
 		}
 
@@ -347,6 +348,7 @@ WRMT_WiiRemoteImpl_Open(WRMT_WiiRemoteImpl *self)
 		if(rc == -1)
 		{
 			WRMT_SetError("Control Socket Connecting Failed.");
+			result = WRMT_IO_ERROR;
 			return result;
 		}
 
@@ -355,6 +357,8 @@ WRMT_WiiRemoteImpl_Open(WRMT_WiiRemoteImpl *self)
 		if(interrupt_socket == -1)
 		{
 			WRMT_SetError("Interrupt Socket Creation Failed.");
+			result = WRMT_IO_ERROR;
+			close(control_socket);
 			return result;
 		}
 
@@ -366,6 +370,8 @@ WRMT_WiiRemoteImpl_Open(WRMT_WiiRemoteImpl *self)
 		if(rc == -1)
 		{
 			WRMT_SetError("Interrupt Socket Connecting Failed.");
+			result = WRMT_IO_ERROR;
+			close(control_socket);
 			return result;
 		}
 
