@@ -2,8 +2,7 @@
 * Copyright (C) 2007 Masahiko SAWAI All Rights Reserved. 
 ************************************************************/
 
-#define MAC_OS_X_VERSION_MIN_REQUIRED MAC_OS_X_VERSION_10_2
-
+#import <AvailabilityMacros.h>
 #import <IOBluetooth/objc/IOBluetoothDevice.h>
 
 @interface IOBluetoothDevice (WiiRemote)
