@@ -6,11 +6,9 @@
 
 #import "WiiRemoteImplement.h"
 
-#define MAC_OS_X_VERSION_MIN_REQUIRED MAC_OS_X_VERSION_10_2
-
+#import <AvailabilityMacros.h>
 #import <Foundation/NSArray.h>
 #import <IOBluetooth/objc/IOBluetoothDeviceInquiry.h>
-#import <IOBluetooth/objc/IOBluetoothDevice.h>
 
 typedef enum WiiRemoteManagerStatus
 {
