@@ -378,7 +378,7 @@ WRMT_WiiRemote_SendReportTypeRequest(WRMT_WiiRemote *self)
 	if (self->function_flag[WRMT_FUNCTION_MOTION])
 		channel |= 0x01;
 	if (self->function_flag[WRMT_FUNCTION_IR])
-		channel |= 0x02;
+		channel |= 0x03;
 
 	DebugLog("channel : 0x%02x\n", channel);
 	WRMT_WiiRemote_ClearOutputBuffer(self);
@@ -632,9 +632,10 @@ WRMT_Sleep(int ms)
 	DebugLog("Bye\n");
 }
 
-void
+int
 WRMT_Update()
 {
+	WRMT_IOReturn result;
 	WRMT_IOReturn rc;
 	DebugLog("Hello\n");
 
@@ -642,9 +643,13 @@ WRMT_Update()
 	{
 		rc = WRMT_Poll();
 	}
-	while (rc == WRMT_IO_SUCCESS);
+	while (rc >= 0);
+
+	result = (rc == WRMT_IO_TIMEOUT) ? WRMT_IO_SUCCESS : WRMT_IO_ERROR;
 	
 	DebugLog("Bye\n");
+	assert(result == WRMT_IO_SUCCESS || result == WRMT_IO_ERROR);
+	return result;
 }
 
 int
@@ -673,6 +678,7 @@ WRMT_Poll()
 	}
 
 	DebugLog("Bye\n");
+	assert(result == WRMT_IO_ERROR || result == WRMT_IO_TIMEOUT || result >= 0);
 	return result;
 }
 
@@ -746,97 +752,99 @@ WRMT_WiiRemote_Close(WRMT_WiiRemote *self)
 }
 
 int 
-WRMT_WiiRemote_IsEnabled(WRMT_WiiRemote *self, WRMT_FunctionType type)
+WRMT_WiiRemote_IsEnabled(WRMT_WiiRemote *self, WRMT_FunctionType function_type)
 {
 	int result;
-	assert(type >= 0 && type < WRMT_NUMBER_OF_FUNCTIONS);
+	assert(function_type >= 0 && function_type < WRMT_NUMBER_OF_FUNCTIONS);
 	WRMT_WiiRemote_Invaliant(self);
-	DebugLog("Hello type == %d\n", type);
+	DebugLog("Hello function_type == %d\n", function_type);
 
-	result = self->function_flag[type];
+	result = self->function_flag[function_type];
 
 	DebugLog("Bye result == %d\n", result);
 	WRMT_WiiRemote_Invaliant(self);
 	return result;
 }
 
-void
-WRMT_WiiRemote_SetEnabled(WRMT_WiiRemote *self, WRMT_FunctionType type,
-	int value)
+WRMT_IOReturn
+WRMT_WiiRemote_SetEnabled(WRMT_WiiRemote *self,
+	WRMT_FunctionType function_type, int value)
 {
-	assert(type >= 0 && type < WRMT_NUMBER_OF_FUNCTIONS);
+	WRMT_IOReturn result = WRMT_IO_SUCCESS;
+	assert(function_type >= 0 && function_type < WRMT_NUMBER_OF_FUNCTIONS);
 	assert(value == 0 || value == 1);
 	WRMT_WiiRemote_Invaliant(self);
-	DebugLog("Hello: type == %d, value == %d\n", type, value);
+	DebugLog("Hello: function_type == %d, value == %d\n", function_type, value);
 
-	if (self->function_flag[type] != value)
+	if (self->function_flag[function_type] != value)
 	{
-		self->function_flag[type] = value;
-		WRMT_WiiRemote_SendReportTypeRequest(self);
-		switch (type)
+		self->function_flag[function_type] = value;
+		result = WRMT_WiiRemote_SendReportTypeRequest(self);
+		if (result != WRMT_IO_SUCCESS) return result;
+
+		switch (function_type)
 		{
 		case WRMT_FUNCTION_CONTINUOUS :
 			break;
 		case WRMT_FUNCTION_MOTION :
 			break;
 		case WRMT_FUNCTION_SPEAKER :
-			WRMT_WiiRemote_SendSpeakerParameters(self);
+			result = WRMT_WiiRemote_SendSpeakerParameters(self);
 			break;
 		case WRMT_FUNCTION_IR :
-			WRMT_WiiRemote_SendIRParameters(self);
+			result = WRMT_WiiRemote_SendIRParameters(self);
 			break;
 		default:
 			break;
 		}
+		if (result != WRMT_IO_SUCCESS) return result;
 	}
 	WRMT_Impl_Sleep(10);
 
 	DebugLog("Bye\n");
 	WRMT_WiiRemote_Invaliant(self);
+	return result;
 }
 
 int
-WRMT_WiiRemote_GetState(WRMT_WiiRemote *self, WRMT_DataType type)
+WRMT_WiiRemote_GetState(WRMT_WiiRemote *self, WRMT_DataType data_type)
 {
-	assert(type >= 0 && type < WRMT_NUMBER_OF_DATA_TYPE);
+	assert(data_type >= 0 && data_type < WRMT_NUMBER_OF_DATA_TYPE);
 	WRMT_WiiRemote_Invaliant(self);
 	DebugLog("Hello\n");
 
-	return self->device_state[type];
+	return self->device_state[data_type];
 }
 
-void
-WRMT_WiiRemote_SetState(WRMT_WiiRemote *self, WRMT_DataType type, int value)
+WRMT_IOReturn
+WRMT_WiiRemote_SetState(WRMT_WiiRemote *self, WRMT_DataType data_type, int value)
 {
-	assert(type == WRMT_DATA_FORCE_FEEDBACK ||
-		type == WRMT_DATA_LEDS ||
-		type == WRMT_DATA_SPEAKER_VOLUME ||
-		type == WRMT_DATA_SPEAKER_SAMPLE_RATE);
+	WRMT_IOReturn result = WRMT_IO_SUCCESS;
+	assert(data_type == WRMT_DATA_FORCE_FEEDBACK ||
+		data_type == WRMT_DATA_LEDS ||
+		data_type == WRMT_DATA_SPEAKER_VOLUME ||
+		data_type == WRMT_DATA_SPEAKER_SAMPLE_RATE);
 	WRMT_WiiRemote_Invaliant(self);
-	DebugLog("Hello type == %d, value == %d\n", type, value);
+	DebugLog("Hello data_type == %d, value == %d\n", data_type, value);
 
-	if (self->device_state[type] != value)
+	if (self->device_state[data_type] != value)
 	{
-		WRMT_IOReturn ioResult;
-
-		self->device_state[type] = value;
-		ioResult = WRMT_WiiRemote_SendDeviceState(self);
-		DebugLog("ioResult : %d\n", ioResult);
-		if (ioResult == WRMT_IO_ERROR)
-		{
-			DebugLog("WRMT_GetError() : %s\n", WRMT_GetError());
-		}
+		self->device_state[data_type] = value;
+		result = WRMT_WiiRemote_SendDeviceState(self);
 	}
 
+	DebugLog("result : %d\n", result);
 	DebugLog("Bye\n");
 	WRMT_WiiRemote_Invaliant(self);
+	assert(result == WRMT_IO_SUCCESS || result == WRMT_IO_ERROR);
+	return result;
 }
 
 WRMT_IOReturn
 WRMT_WiiRemote_WriteDataToMemory(WRMT_WiiRemote *self,
 	int address, const unsigned char* data_ptr, size_t data_size)
 {
-	WRMT_IOReturn result = WRMT_IO_ERROR ;
+	WRMT_IOReturn result;
 	WRMT_WiiRemote_Invaliant(self);
 	assert(data_ptr != NULL);
 	assert(data_size >=1 && data_size <= 16);
@@ -862,6 +870,7 @@ WRMT_WiiRemote_WriteDataToMemory(WRMT_WiiRemote *self,
 
 	DebugLog("Bye\n");
 	WRMT_WiiRemote_Invaliant(self);
+	assert(result == WRMT_IO_ERROR || result == WRMT_IO_SUCCESS);
 	return result;
 }
 
