@@ -10,6 +10,14 @@ extern "C" {
 
 #include <wiiremote.h> 
 
+#define WRMT_CheckButton WRMT_CheckButtonAny
+#define WRMT_CheckButtonAny(buttons, button_mask) ((buttons) & (button_mask))
+#define WRMT_CheckButtonAll(buttons, button_mask) (((buttons) & (button_mask)) == (button_mask))
+
+#define WRMT_CheckLED WRMT_CheckLEDAny
+#define WRMT_CheckLEDAny(leds, led_mask) ((leds) & (led_mask))
+#define WRMT_CheckLEDAll(leds, led_mask) (((leds) & (led_mask)) == (led_mask))
+
 #define WRMT_WiiRemote_CheckButton WRMT_WiiRemote_CheckButtonAny
 #define WRMT_WiiRemote_CheckButtonAny(wiiremote, button_mask) (WRMT_WiiRemote_GetState((wiiremote), WRMT_DATA_BUTTONS) & (button_mask))
 #define WRMT_WiiRemote_CheckButtonAll(wiiremote, button_mask) ((WRMT_WiiRemote_GetState((wiiremote), WRMT_DATA_BUTTONS) & (button_mask)) == (button_mask))
