@@ -53,8 +53,6 @@ int main(int argc, char *argv[])
 		}
 		fprintf(stderr, "[%d] WRMT_WiiRemote_Open() Success.\n", i);
 
-		WRMT_WiiRemote_SetEnabled(wiiremotes[i], WRMT_FUNCTION_CONTINUOUS, 0);
-		WRMT_WiiRemote_SetEnabled(wiiremotes[i], WRMT_FUNCTION_MOTION, 1);
 		WRMT_WiiRemote_SetEnabled(wiiremotes[i], WRMT_FUNCTION_IR, 1);
 	}
 
